"""nester__UeRS.py: processa listas aninhadas"""
def print_lol(the_list, indent = False, level = 0):
  """Imprime os itens de uma lista na tela, inclusive os itens aninhados.
  the_list: lista a ser impressa de forma recursiva.
  indent: informa se havera indentamento ou nao.
  level: informa o nível de indentamento, se houver."""
  for each_item in the_list:
    if isinstance(each_item, list):
      print_lol(each_item, indent, level+1)
    else:
      if indent:
        for tab_stop in range(level):
          print("\t", end ='')
        
      print(each_item)



from distutils.core import setup

setup(
  name = 'nester__UeRS',
  version = '1.3.1',
  py_modules = ['nester__UeRS'],
  author = 'uendelrocha',
  author_email = 'uendelrocha@gmail.com',
  url = 'https://www.facebook.com/uendelrocha',
  description = 'Uma simples impressora de listas aninhadas',
  )
